| Title: | Cases of COVID-19 in Tunisia |
|---|---|
| Description: | Data personnally collected about the spread of COVID-19 (SARS-COV-2) in Tunisia. |
| Authors: | Mouna Belaid [aut, cre] |
| Maintainer: | Mouna Belaid <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-06-06 07:28:38 UTC |
| Source: | https://github.com/mounabelaid/covid19tunisia |
Get info about this dataset
get_info_covid19tunisia()get_info_covid19tunisia()
A tibble with information about where the data is pulled from, details about the dataset, what the data types are, etc.
get_info_covid19tunisia()get_info_covid19tunisia()
Refresh data
refresh_covid19tunisia(verbose = TRUE)refresh_covid19tunisia(verbose = TRUE)
verbose |
Should messages about what's going on be displayed? |
A tibble of the most up to date per-day data on cases of COVID-19 in Tunisia, ordered by date descending.
refresh_covid19tunisia()refresh_covid19tunisia()